---
name: Feature Request
about: Suggest an idea for Chuck
labels: enhancement
---

**Problem**
What problem does this solve?

**Proposed solution**
Describe what you'd like to happen.

**Alternatives considered**
Any alternative solutions you've thought about.
